Function nix::sys::ioctl::read
[−]
[src]
pub unsafe fn read<T>(fd: Fd, op: ioctl_op_t) -> Result<T>
Ioctl call that is expected to return a result but which does not take any additional arguments on the input side
This function will allocate allocate space for and returned an owned reference to the result.